@@ -7,6 +7,9 @@ from truvari.annos.repmask import rmk_main
 from truvari.annos.remap import remap_main
 from truvari.annos.hompct import hompct_main
 from truvari.annos.numneigh import numneigh_main
+from truvari.annos.svinfo import svinfo_main
+from truvari.annos.bpovl import bpovl_main
+from truvari.annos.density import density_main
 
 __all__ = [
     'gcpct_main',
@@ -17,4 +20,7 @@ __all__ = [
     'remap_main',
     'hompct_main',
     'numneigh_main',
+    'svinfo_main',
+    'bpovl_main',
+    'density_main'
 ]
