@@ -25,7 +25,7 @@ except OSError:
 import truvari
 
 try:
-    from setproctitle import setproctitle # pylint: disable=import-error,useless-suppression
+    from setproctitle import setproctitle  # pylint: disable=import-error,useless-suppression
 except ModuleNotFoundError:
     def setproctitle(_):
         """ dummy function """
@@ -34,6 +34,7 @@ except ModuleNotFoundError:
 # Data shared with workers; must be populated before workers are started.
 grm_shared = types.SimpleNamespace()
 
+
 def make_kmers(ref, entry, kmer=25):
     """
     Make ref/alt kmers
@@ -45,8 +46,10 @@ def make_kmers(ref, entry, kmer=25):
     end = entry.stop
     try:
         reflen = ref.get_reference_length(entry.chrom)
-        up = ref.fetch(entry.chrom, max(start - kmer, 0), min(start + kmer, reflen))
-        dn = ref.fetch(entry.chrom, max(end - kmer, 0), min(end + kmer, reflen))
+        up = ref.fetch(entry.chrom, max(start - kmer, 0),
+                       min(start + kmer, reflen))
+        dn = ref.fetch(entry.chrom, max(end - kmer, 0),
+                       min(end + kmer, reflen))
 
         if len(up) < kmer or len(dn) < kmer:
             return None
@@ -56,7 +59,7 @@ def make_kmers(ref, entry, kmer=25):
         # alternate
         hap = up[:kmer] + seq + dn[-kmer:]
         return up, dn, hap[:kmer * 2], hap[-kmer * 2:]
-    except Exception as e: # pylint: disable=broad-except
+    except Exception as e:  # pylint: disable=broad-except
         logging.warning(f"{e} for {str(entry)[:20]}...")
         return None
 
@@ -83,10 +86,9 @@ def cig_pctsim(cigar):
 
 def map_stats(aligner, kmer, chrom=None, pos=None):
     """
-    Maps the kmer and returns the
-    max/min
-    if chrom/pos is provided:
-        remove any hits that maps over this position. This is a filter of the reference - we want to know where *else* it hits
+    Maps the kmer and returns the max/min
+    if chrom/pos is provided remove any hits that maps over this position. This
+    is a filter of the reference - we want to know where *else* it hits
     """
     nhits = 0
     dir_hits = 0
@@ -245,7 +247,8 @@ def process_entries(ref_section):
         entry = line_to_entry(line)
         if next_progress == 0:
             next_progress = 1000
-            setproctitle(f"grm processing {entry.chrom}:{entry.start} in {ref_name}:{start}-{stop}")
+            setproctitle(
+                f"grm processing {entry.chrom}:{entry.start} in {ref_name}:{start}-{stop}")
         else:
             next_progress -= 1
         if "SVLEN" not in entry.info:
@@ -258,7 +261,8 @@ def process_entries(ref_section):
         ref_up, ref_dn, alt_up, alt_dn = kmers
         ty = truvari.entry_variant_type(entry)
 
-        result = ["%s:%d-%d.%s" % (entry.chrom, entry.start, entry.stop, entry.alts[0])]
+        result = ["%s:%d-%d.%s" %  # pylint: disable=consider-using-f-string
+                  (entry.chrom, entry.start, entry.stop, entry.alts[0])]
         if ty == "INS":
             # Only want a single reference kmer
             ref_stats = map_stats(aligner, ref_up, entry.chrom, entry.start)
@@ -282,37 +286,6 @@ def process_entries(ref_section):
     return data
 
 
-def ref_ranges(reference, chunk_size=10000000):
-    """
-    Chunk reference into pieces
-    """
-    ref = pysam.FastaFile(reference)
-    for ref_name in ref.references: # pylint: disable=not-an-iterable
-        final_stop = ref.get_reference_length(ref_name)
-        start = 0
-        stop = start + chunk_size
-        while stop < final_stop:
-            yield ref_name, start, stop
-            start = stop
-            stop += chunk_size
-        yield ref_name, start, final_stop
-
-def bed_ranges(bed, chunk_size=10000000):
-    """
-    Chunk bed ranges into pieces
-    """
-    with open(bed, 'r') as fh:
-        for line in fh:
-            data = line.strip().split('\t')
-            start = int(data[1])
-            final_stop = int(data[2])
-            stop = start + chunk_size
-            while stop < final_stop:
-                yield data[0], start, stop
-                start = stop
-                stop += chunk_size
-            yield data[0], start, final_stop
-
 def grm_main(cmdargs):
     """
     Builds a graph-genome from the vcf and reference,
@@ -329,9 +302,9 @@ def grm_main(cmdargs):
         sys.exit(1)
     args = parse_args(cmdargs)
     if not args.regions:
-        m_ranges = ref_ranges(args.reference)
+        m_ranges = truvari.ref_ranges(args.reference)
     else:
-        m_ranges = bed_ranges(args.regions)
+        m_ranges = truvari.bed_ranges(args.regions)
 
     grm_shared.aligner = BwaAligner(args.reference, '-a')
     header = ["key"]
